@@ -96,6 +96,7 @@ class InfrastructureKPI(EmbeddedDocument):
 class UserCommit(EmbeddedDocument):
     ''' User Commit '''
     sha = StringField(required=True)
+    name = StringField(required=True)
 
 
 class UserEvent(Document):
@@ -172,6 +173,10 @@ class PrEvent(Document):
     file_count = DictField()
     tokens = DictField()
     files = ListField()
+    omitted_files = ListField()
+
+    # Size and details
+    total_length = IntField(default=0)
     comment_percent = FloatField()
     space_percent = FloatField()
 
